============
Salary Stone
============


.. image:: https://img.shields.io/pypi/v/salary_stone.svg
        :target: https://pypi.python.org/pypi/salary_stone

.. image:: https://img.shields.io/travis/nickmayn/salary_stone.svg
        :target: https://travis-ci.com/nickmayn/salary_stone

.. image:: https://readthedocs.org/projects/salary-stone/badge/?version=latest
        :target: https://salary-stone.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/nickmayn/salary_stone/shield.svg
     :target: https://pyup.io/repos/github/nickmayn/salary_stone/
     :alt: Updates



The purpose of this project is to host the methods related to the salary stone project. These include a skill extractor from text, a model that allows for prediction of and a variety of other method.


* Free software: Apache Software License 2.0
* Documentation: https://salary-stone.readthedocs.io.


Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
